@@ -77,9 +77,9 @@ def mutation_create_media_object(*, title: str, contributor: str, creator: str,
 
 @docstring_interpolate("mediaobject_args", MEDIAOBJECT_ARGS_DOCS)
 def mutation_update_media_object(identifier: str, *, name: str = None, title: str = None, description: str = None,
-                                 date: str = None, creator: str = None, contributor: str = None,
-                                 format_: str = None, encodingformat: str = None, source: str = None, license: str = None,
-                                 subject: str = None, contenturl: str = None, language: str = None, inlanguage:str = None):
+                                 date: str = None, creator: str = None, contributor: str = None, format_: str = None,
+                                 encodingformat: str = None, source: str = None, license: str = None, subject: str = None,
+                                 url: str = None, contenturl: str = None, language: str = None, inlanguage:str = None):
     """Returns a mutation for updating a media object object.
 
     Arguments:
@@ -112,6 +112,7 @@ def mutation_update_media_object(identifier: str, *, name: str = None, title: st
         "encodingFormat": encodingformat,
         "source": source,
         "subject": subject,
+        "url": url,
         "contentUrl": contenturl,
         "license": license,
         "inLanguage": inlanguage,
